@@ -1,17 +1,33 @@
 use std::fs;
+use std::io::Error;
 use std::path::Path;
 use tiny_http::{Header, Request, Response, StatusCode};
-use std::io::Error;
 pub fn serveFolder(rq: Request, path: &str) -> Result<(), Error> {
     let entries = fs::read_dir(Path::new(&("./".to_owned() + &path)));
     let entries = match entries {
-        Err(why) => fs::read_dir("./").unwrap(),
+        Err(_why) => fs::read_dir("./").unwrap(),
         Ok(value) => value,
     };
     let mut TheResponse: String = String::from(format!(
         "<html><body><h1>Scanning directory {}</h1></br>",
         &path
     ));
+    let p = &("./".to_owned() + &path);
+    let parent = Path::new(p).parent();
+    //println!("{}", parent);
+
+    match parent {
+        Some(parent) => match parent.to_str() {
+            Some(parent) => {
+                TheResponse = TheResponse
+                    + "<a href = "
+                    + parent
+                    + " > <b> .. (parent folder) </b> </a></br>";
+            }
+            None => {}
+        },
+        None => {}
+    }
 
     for entry in entries {
         let path = entry.unwrap().path();
